# Distributed under the OSI-approved BSD 3-Clause License.  See accompanying
# file Copyright.txt or https://cmake.org/licensing for details.
# Copyright (c) 2020 Pavel "Malo" Skrylev <majioa@yandex.ru>
#
#[=======================================================================[.rst:
FindMeshSDFilter

Find MeshSDFilter include folders and libraries

Use as follows:

find_library(MeshSDFilter)

This module finds headers and requested component libraries. For the former
case results are reported in variables:

  MESHSDFILTER_FOUND             - True if headers and requested libraries were found
  MESHSDFILTER_INCLUDE_DIR       - MeshSDFilter include directories

This module reads hints about search locations from variables:

  MESHSDFILTER_ROOT_HINTS        - Preferred installation prefix
  MESHSDFILTER_INCLUDE_DIR_HINTS - Preferred include directory e.g. <prefix>/include

  Example to find MeshSDFilter headers only:

  find_package(MeshSDLibrary)
  if(MESHSDFILTER_FOUND)
    include_directories(${MESHSDFILTER_INCLUDE_DIR})
  endif()

#]=======================================================================]


if(NOT MESHSDFILTER_INCLUDE_DIR)
   find_path(MESHSDFILTER_INCLUDE_DIR
      NAMES
         SDFilter.h
      HINTS
         ENV MESHSDFILTER_INCLUDE_DIR_HINTS
         ENV MESHSDFILTER_ROOT_HINT
      PATHS
         ${CMAKE_INSTALL_PREFIX}/include
      PATH_SUFFIXES
         meshsdfilter
   )

   if(MESHSDFILTER_INCLUDE_DIR)
      set(MESHSDFILTER_FOUND TRUE)

      find_package(Eigen3 REQUIRED)

      add_library(MeshSDLibrary INTERFACE)
      target_include_directories(MeshSDLibrary
         INTERFACE
            ${MESHSDFILTER_INCLUDE_DIR}
            ${EIGEN3_INCLUDE_DIR})
      target_link_libraries(MeshSDLibrary
         INTERFACE
            OpenMeshCore)

      include(FindPackageHandleStandardArgs)
      find_package_handle_standard_args(MeshSDFilter DEFAULT_MSG MESHSDFILTER_INCLUDE_DIR)

      message(STATUS "MeshSDFilter found with headers in ${MESHSDFILTER_INCLUDE_DIR}")

      mark_as_advanced(MESHSDFILTER_INCLUDE_DIR)
   endif()
endif(NOT MESHSDFILTER_INCLUDE_DIR)
